@@ -82,6 +82,7 @@ ItemEditorPrivate::ItemEditorPrivate(Akonadi::IncidenceChanger *changer, EditorI
     mFetchScope.setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
     mFetchScope.setFetchTags(true);
     mFetchScope.tagFetchScope().setFetchIdOnly(false);
+    mFetchScope.setFetchRemoteIdentification(false);
 
     mChanger
         = changer ? changer : new Akonadi::IncidenceChanger(new IndividualMailComponentFactory(
@@ -350,8 +351,6 @@ void EditorItemManager::save()
             Q_ASSERT(d->mItemUi->selectedCollection().isValid());
             Q_ASSERT(d->mItem.parentCollection().isValid());
 
-            // ETM and the KSelectionProxyModel has a bug wrt collections moves, so this is disabled.
-            // To test this, enable the collection combo-box and remove the following assert.
             qCDebug(INCIDENCEEDITOR_LOG) << "Moving from"
                                          << d->mItem.parentCollection().id() << "to"
                                          << d->mItemUi->selectedCollection().id();
